MapStruct Processor 1.7.0.Beta1 API

Packages
Package
Description
This package and it sub-packages contain the implementation of the MapStruct annotation processor.
Provides built-in conversions between primitive and wrapper types, strings, dates etc.
 
Meta-model of mapper types, their methods, mappings between properties etc.
 
Meta-model of assignments.
helper classes used in BeanMappingMethod
Contains types which are shared between the intermediary mapping method model ("source model") and the mapper model.
 
 
Intermediary representation of mapping methods as retrieved from via the annotation processing API.
Contains "built-in methods" which may be added as private methods to a generated mapper.
Provides strategies for selecting a matching mapping or factory method when mapping from one attribute to another or instantiating the target type of a mapping method, respectively.
Provides access to the options passed to the annotation processor.
Contains model processors which perform tasks such as retrieving mapping methods, creating a model representation and writing the model into Java source files.
Contains all helper classes for the MapperCreationProcessor
Several helper types dealing with collection types, option management etc.
 
 
Provides various version information
Infrastructure for dealing with the FreeMarker template engine.
SPI (service provider interface) contracts to be implemented for advanced use cases.
Utility classes for the SPI package.