Uses of Enum
org.mapstruct.ap.internal.util.NullabilityResolver.Nullability
Packages that use NullabilityResolver.Nullability
Package
Description
Meta-model of mapper types, their methods, mappings between properties etc.
Several helper types dealing with collection types, option management etc.
-
Uses of NullabilityResolver.Nullability in org.mapstruct.ap.internal.model
Methods in org.mapstruct.ap.internal.model that return NullabilityResolver.NullabilityModifier and TypeMethodDescriptionMappingBuilderContext.getNullabilityInMapperScope(Element element) Resolves the JSpecify nullability of an element declared directly on the mapper (e.g. a mapping method's return type or one of its source parameters), using the mapper type's@NullMarkedscope as the enclosing scope for unannotated elements.Methods in org.mapstruct.ap.internal.model with parameters of type NullabilityResolver.NullabilityModifier and TypeMethodDescriptionCollectionAssignmentBuilder.sourceJSpecifyNullability(NullabilityResolver.Nullability sourceJSpecifyNullability) -
Uses of NullabilityResolver.Nullability in org.mapstruct.ap.internal.util
Methods in org.mapstruct.ap.internal.util that return NullabilityResolver.NullabilityModifier and TypeMethodDescriptionNullabilityResolver.getNullability(Element element, BooleanSupplier enclosingTypeNullMarked) Determines the nullability of an accessor element based on JSpecify annotations.NullabilityResolver.getSetterNullability(Element element, BooleanSupplier enclosingTypeNullMarked) Determines the nullability of a write-accessor element — either a setter method or a field.Returns the enum constant of this type with the specified name.static NullabilityResolver.Nullability[]NullabilityResolver.Nullability.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.mapstruct.ap.internal.util with parameters of type NullabilityResolver.NullabilityModifier and TypeMethodDescriptionNullabilityResolver.requiresNullCheck(NullabilityResolver.Nullability sourceNullability, NullabilityResolver.Nullability targetNullability) Determines whether a null check is required for a property mapping based on JSpecify annotations on the source and target elements.