Package org.mapstruct.ap.internal.util
Enum NullabilityResolver.Nullability
java.lang.Object
java.lang.Enum<NullabilityResolver.Nullability>
org.mapstruct.ap.internal.util.NullabilityResolver.Nullability
- All Implemented Interfaces:
Serializable,Comparable<NullabilityResolver.Nullability>,java.lang.constant.Constable
- Enclosing class:
NullabilityResolver
Represents the effective nullability of a source or target element.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionThe element is effectively non-null — either directly annotated@NonNull, or within a@NullMarkedscope without a closer@NullUnmarkedor@Nullableoverride.The element is explicitly annotated@Nullable.Nullability is unspecified — no annotation applies and the element is not within an applicable@NullMarkedscope (or JSpecify support is disabled). -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this type with the specified name.static NullabilityResolver.Nullability[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
NON_NULL
The element is effectively non-null — either directly annotated@NonNull, or within a@NullMarkedscope without a closer@NullUnmarkedor@Nullableoverride. -
NULLABLE
The element is explicitly annotated@Nullable. -
UNKNOWN
Nullability is unspecified — no annotation applies and the element is not within an applicable@NullMarkedscope (or JSpecify support is disabled).
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-